@@ -19,7 +19,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * 
- * $Id: disk_stat.c,v 1.20 2004/02/22 15:25:22 nold Exp $
+ * $Id: disk_stat.c,v 1.21 2004/08/08 15:06:29 nold Exp $
  *
  */
 
@@ -464,7 +464,7 @@ static int check_newstyle_25(disk_stat_t ds)
 	}
 
 	while (!feof(stat) && !succ) {
-		if (fscanf(stat, "%u %u hd%9s %u %u %u %u %u %u %u %u %u %u %u",
+		if (fscanf(stat, "%u %u %9s %u %u %u %u %u %u %u %u %u %u %u",
 			   &dummy, &dummy, ch_dummy,
 			   &dummy, &dummy, &dummy, &dummy, &dummy, &dummy,
 			   &dummy, &dummy,
@@ -496,7 +496,7 @@ static void update_io_25(disk_stat_t ds)
 			break;
 		
 		ret = sscanf(line,
-		           "%u %u hd%9s %u %u %u %u %u %u %u %u %u %u %u",
+		           "%u %u %9s %u %u %u %u %u %u %u %u %u %u %u",
 		           &major, &minor, ch_dummy,
 		           &rio, &dummy, &rblk, &dummy, &wio, &dummy, &wblk,
 		           &dummy, &dummy, &dummy, &dummy);
